pub struct AggregatorServiceConfig {
pub aggregator: AggregatorConfig,
pub max_name_length: usize,
pub max_tag_key_length: usize,
pub max_tag_value_length: usize,
pub max_flush_bytes: usize,
}Expand description
Parameters used for metric aggregation.
Fields
aggregator: AggregatorConfigThe config used by the internal aggregator.
max_name_length: usizeThe length the name of a metric is allowed to be.
Defaults to 200 bytes.
max_tag_key_length: usizeThe length the tag key is allowed to be.
Defaults to 200 bytes.
max_tag_value_length: usizeThe length the tag value is allowed to be.
Defaults to 200 chars.
max_flush_bytes: usizeThe approximate maximum number of bytes submitted within one flush cycle.
This controls how big flushed batches of buckets get, depending on the number of buckets, the cumulative length of their keys, and the number of raw values. Since final serialization adds some additional overhead, this number is approximate and some safety margin should be left to hard limits.
Implementations
Sourceimpl AggregatorServiceConfig
impl AggregatorServiceConfig
Sourcepub fn timestamp_range(&self) -> Range<UnixTimestamp>
pub fn timestamp_range(&self) -> Range<UnixTimestamp>
Returns the valid range for metrics timestamps.
Metrics or buckets outside of this range should be discarded.